AioCrypto
==================

.. image:: https://img.shields.io/badge/telegram-ErVinTract-blue.svg?style=flat
   :target: https://t.me/ErVinTract
   :alt: [Telegram] ErVinTract

.. image:: https://img.shields.io/pypi/v/AioCrypto.svg?style=flat
   :target: https://pypi.python.org/pypi/AioCrypto
   :alt: PyPi Package Version

.. image:: https://img.shields.io/pypi/dm/AioCrypto.svg?style=flat
   :target: https://pypi.python.org/pypi/AioCrypto
   :alt: PyPi downloads

.. image:: https://img.shields.io/pypi/pyversions/AioCrypto.svg?style=flat
   :target: https://pypi.python.org/pypi/AioCrypto
   :alt: Supported python versions

.. image:: https://img.shields.io/badge/AioCrypto-1.1.1-blue.svg?style=flat
   :target: https://help.crypt.bot/crypto-pay-api
   :alt: Crypto API

.. image:: https://img.shields.io/github/issues/ErVinTract/aiocrypto.svg?style=flat-square
   :target: https://github.com/ErVinTract/AioCrypto/issues
   :alt: Github issues

.. image:: https://img.shields.io/pypi/l/AioCrypto.svg?style=flat-square
   :target: https://opensource.org/licenses/Apache-2.0
   :alt: Apache-2.0 license


**AioCrypto** is a fairly simple and convenient library for working with the `Crypto API <https://help.crypt.bot/crypto-pay-api>`_, written in Python 3.8+ with `asyncio <https://docs.python.org/3/library/asyncio.html>`_ and `aiohttp <https://github.com/aio-libs/aiohttp>`_.

**Official aiocrypto resources**

- News: `@CryptoBotRu <https://t.me/CryptoBotRU>`_
- Community: `@CryptoBotRussian <https://t.me/CryptoBotRussian>`_
- Pip: `AioCrypto <https://pypi.python.org/pypi/aiocrypto>`_
- Source: `Github repo <https://github.com/ErVinTract/AioCrypto>`_
- Issues/Bug tracker: `Github issues tracker <https://github.com/ErVinTract/AioCrypto/issues>`_
